use chrono_tz::Tz;
use log::warn;
use poise::{CreateReply, Modal};

use crate::{
    commands::autocomplete::{time_hint_autocomplete, timezone_autocomplete},
    models::reminder::create_reminder,
    ApplicationContext, Context, Error,
};

#[derive(poise::Modal)]
#[name = "Reminder"]
struct ContentModal {
    #[name = "Content"]
    #[placeholder = "Message..."]
    #[paragraph]
    #[max_length = 2000]
    content: String,
}

/// Create a reminder with multi-line content. Press "+4 more" for other options.
#[poise::command(
    slash_command,
    identifying_name = "multiline",
    default_member_permissions = "MANAGE_GUILD"
)]
pub async fn multiline(
    ctx: ApplicationContext<'_>,
    #[description = "A description of the time to set the reminder for"]
    #[autocomplete = "time_hint_autocomplete"]
    time: String,
    #[description = "Channel or user mentions to set the reminder for"] channels: Option<String>,
    #[description = "(Patreon only) Time to wait before repeating the reminder. Leave blank for one-shot reminder"]
    interval: Option<String>,
    #[description = "(Patreon only) For repeating reminders, the time at which the reminder will stop repeating"]
    expires: Option<String>,
    #[description = "Set the TTS flag on the reminder message, similar to the /tts command"]
    tts: Option<bool>,
    #[description = "Set a timezone override for this reminder only"]
    #[autocomplete = "timezone_autocomplete"]
    timezone: Option<String>,
) -> Result<(), Error> {
    let tz = timezone.map(|t| t.parse::<Tz>().ok()).flatten();
    let data_opt = ContentModal::execute(ctx).await?;

    match data_opt {
        Some(data) => {
            create_reminder(
                Context::Application(ctx),
                time,
                data.content,
                channels,
                interval,
                expires,
                tts,
                tz,
            )
            .await
        }

        None => {
            warn!("Unexpected None encountered in /multiline");
            Ok(Context::Application(ctx)
                .send(CreateReply::default().content("Unexpected error.").ephemeral(true))
                .await
                .map(|_| ())?)
        }
    }
}
