use crate::{consts::MINUTE, models::CtxData, Context, Error};

/// Nudge all future reminders on this channel by a certain amount (don't use for DST! See `/offset`)
#[poise::command(
    slash_command,
    identifying_name = "nudge",
    default_member_permissions = "MANAGE_GUILD"
)]
pub async fn nudge(
    ctx: Context<'_>,
    #[description = "Number of minutes to nudge new reminders by"] minutes: Option<isize>,
    #[description = "Number of seconds to nudge new reminders by"] seconds: Option<isize>,
) -> Result<(), Error> {
    let combined_time = minutes.map_or(0, |m| m * MINUTE as isize) + seconds.map_or(0, |s| s);

    if combined_time < i16::MIN as isize || combined_time > i16::MAX as isize {
        ctx.say("Nudge times must be less than 500 minutes").await?;
    } else {
        let mut channel_data = ctx.channel_data().await.unwrap();

        channel_data.nudge = combined_time as i16;
        channel_data.commit_changes(&ctx.data().database).await;

        ctx.say(format!("Future reminders will be nudged by {} seconds", combined_time)).await?;
    }

    Ok(())
}
