use crate::{models::CtxData, Context, Error};

/// Add an item to the channel todo list
#[poise::command(
    slash_command,
    rename = "add",
    guild_only = true,
    identifying_name = "todo_channel_add",
    default_member_permissions = "MANAGE_GUILD"
)]
pub async fn add(
    ctx: Context<'_>,
    #[description = "The task to add to the todo list"] task: String,
) -> Result<(), Error> {
    // ensure channel is cached
    let _ = ctx.channel_data().await;

    sqlx::query!(
        "
        INSERT INTO todos (guild_id, channel_id, value)
        VALUES (
            (SELECT id FROM guilds WHERE guild = ?),
            (SELECT id FROM channels WHERE channel = ?),
            ?
        )
        ",
        ctx.guild_id().unwrap().get(),
        ctx.channel_id().get(),
        task
    )
    .execute(&ctx.data().database)
    .await
    .unwrap();

    ctx.say("Item added to todo list").await?;

    Ok(())
}
